pycounter API Docs
==================

pycounter.report module
-----------------------

.. module:: pycounter.report

Commonly-used function
^^^^^^^^^^^^^^^^^^^^^^

.. autofunction:: parse

Classes
^^^^^^^

.. autoclass:: CounterReport
   :members:

.. autoclass:: CounterEresource
   :members:

.. autoclass:: CounterJournal
   :members:

.. autoclass:: CounterBook
   :members:

.. autoclass:: CounterDatabase
   :members:


Other functions
^^^^^^^^^^^^^^^
These are mostly for internal use by the module, but are available to be
called directly if necessary

.. autofunction:: format_stat
.. autofunction:: parse_generic
.. autofunction:: parse_separated
.. autofunction:: parse_xlsx


pycounter.sushi module
----------------------
.. module:: pycounter.sushi

Commonly-used function
^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: get_report

Other functions
^^^^^^^^^^^^^^^
.. autofunction:: get_sushi_stats_raw
